#[non_exhaustive]pub enum Error {
BinCountTooLarge {
bins: usize,
},
ThresholdOutOfRange {
threshold: f64,
},
}Available on crate features
std or alloc only.Expand description
Error returned by Detector::try_new when the provided Options
are inconsistent.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BinCountTooLarge
N_ACCUM * bins overflows usize, or bins > u32::MAX (the bin
lookup table stores indices as u32).
ThresholdOutOfRange
threshold is outside the documented [0.0, 1.0] range.
Implementations
Sourceimpl Error
impl Error
Sourcepub const fn is_bin_count_too_large(&self) -> bool
pub const fn is_bin_count_too_large(&self) -> bool
Returns true if this value is of type BinCountTooLarge. Returns false otherwise
Sourcepub const fn is_threshold_out_of_range(&self) -> bool
pub const fn is_threshold_out_of_range(&self) -> bool
Returns true if this value is of type ThresholdOutOfRange. Returns false otherwise