#[non_exhaustive]pub enum Method {
Floor,
Ceiling,
}Available on crate features
std or alloc only.Expand description
Which direction of threshold crossing counts as a fade.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Floor
Fade detected when mean pixel intensity falls below threshold.
Matches the classic “fade to black” case and is the default.
Ceiling
Fade detected when mean pixel intensity rises above threshold
(fade to white, or overexposure detection).
Implementations